# Software Citation Guidance Task Force Call

Wednesday 16 January 2019

## GitHub Issue

The main GitHub issue is here:
https://github.com/force11/force11-sciwg/issues/56

## Working Document

The working document for this meeting is here: https://docs.google.com/document/d/1IBax3IGla6VLiY1dIiVH8V0pOJdqIigs8M_4omN0UBo/edit#

## Notes

This meeting focused on discussing guidance for reviewers.

### Background

The previous meeting suggested that more guidance in the form of checklists was required to ensure that policies and processes were being applied correctly.

### Assumptions

We assume that it is clear to the reviewer that software should be cited in the submission. This can be made clear in review guidelines, and should be mirrored in the author guidelines.

We assume no assumptions on availability. Code should be cited regardless of who wrote it; we do not start with the assumption that only the article author’s code is used.

We assume that this checklist applies to citations of the software package itself and not necessarily only artefacts e.g. science paper.

We do not assume that all software cited should be open and available to all.

### What are the most important things to check?

Participants on the call suggested the following things to check, which broadly fall into three categories:

1. Is software being recognised?

  * Are there references to software packages in the methodology section where it looks clear that software has been used (e.g. data analysis has been conducted, simulations have been run)?

  * Do the results in the submission suggest that software has been used to generate them, but no software is named/cited?
    * Software is named but not cited: Make sure the software citation follows the author guidelines/is in line with the other questions.
    * No software is named: Request authors to edit accordingly/mention this in review/submission cannot be accepted without revisions

  * Are software (plural) relevant to the outcome cited?


2. Is the software citation following best practice?

  * Is the reference to the software clearly indicated or is it implied (i.e. footnote)?

  * Does the reference lead to a unique instance of the code?

  * Will it be possible to determine the version of the software used to produce the submission from the reference item?

  * Is the software included in the reference list?

  * Was the preferred citation used?


3. Is software that is cited accessible:

  * Code is accessible for the reviewer to look at and assess

  * Code has been archived in a “trusted” digital repository (with an appropriate license?) and citation refers to specific version

### Questions arising that were discussed

1. Are we talking to any editors of journals about this?

  * We have representation from journal editors on the WG (AAS, JORS, JOSS on this call), and have also talked to other editors. However these have mostly been in the "enthusiastic/interested about software citation" category.

  * Offer from Anita (Elsevier) and Sowmya (Nature Research, Springer Nature) to take the guidance and run by journals they represent.

  * Could put together (with permission) a list of the journals and editors that have participated in the process of drafting the guidance. This may be helpful to get buy in from others.

  * Many journals have policies that encourage data and software citation. But on the whole, we aren't actually seeing much citation of either data or software.

  * May be good to setup an initiative that people could sign up to, similar to something like http://www.copdess.org/enabling-fair-data-project/enabling-fair-project-resources/

2. Do we need more or less granularity in terms of how software should be cited?

  * A checklist that asks "Is all the software used for these results cited in the references" would be a good start!

  * More granularity in software citation not required, but more granularity about when (and what type) of software should be cited

  * Another approach: "How do the authors discuss the software tools used in this research? Are those tools mentioned by name in the text and cited (by paper or direct reference to a code) in the manuscript's bibliography?"

  * Existing guidance whether a software shold be cited: http://mr-c.github.io/shouldacite/index.html
    * This list proved contentious

3. Can we make software citation guidance as similar / identical to data citation?

  * To get adoption we need a very simple set of instructions, as alike to data citation as we can make them; then to link to complexities if they are needed

  * Should the outcome of this group be along the lines of what RDA is trying to do with a tiered data availability and data citation policy?

  * Software may appear in more / different places in the research workflow, and therefor the paper, that data

  * Where the place in the workflow is the same for software and data citation, the guidance should be a similar as possible. But there's also a recognition that the way that authors refer to software and data isn't always at the same places in the workflow they describe in a paper.
    * However it would get very complicated if there were a complete divergence in Guidance
    * Perhaps a starting point will be to distinguish between software and data.

  * There is also the issue of promoting citing software and so the things publishers do to encourage it - that's kinda why data availability statements were introduced. At some point they may become redundant as authors start doing the things we're currently promoting as part of their normal practice.

  * Would be useful to describe a few common concrete use cases / vignettes that illustrate the different types of situations we might encounter for different domains (if that's not already being done); where software integrates into the researchers workflow - this is probably something where domains differ, and guidelines should be adapted accordingly?

4. What should we be looking at as a matter of urgency to provide input into guidance?

  * Distill the principles into a flowchart-like form for use by reviewers? (Is this the flowchart that's being worked on at the moment by, I think, Daina et al.?)

  * Before we provide guidance for reviewers, it seems to me we should look at this from the perspective of the researcher/author and provide guidance for them. That'll very readily translate into guidance for reviewers, editors etc.
    * E.g. ICMS guidance by Dan and Neil: [insert link]
    * Allen: I guess I've been seeing it as a simple "I used this collection software to generate significant things in this publication, and here's the specific versions that was used (with pointers to metadata rich, durable landing pages)
    * Stephan: I had drafted a minimal thing a while ago re this: https://research-software.org/citation/researchers/

### Questions arising to be considered for the future

* Should we have two separate sets of guidance, one for if it is the author's code being cited, and one for if it is someone else's?

* Should we be providing quick methods for people to assess whether code is cited but hidden in the text? Eg search paper for keywords such as software, code, github, gitlab, bitbucket etc

* Should software being cited be accessible? E.g. if it points to a 404?

* What do we mean by "trusted" with respect to deposit in a trusted repository? Is it a binary thing, or are there levels?

* Should we be asking reviewers to check if the "preferred citation" has been used?
  * Is this too difficult to check?
  * What if the preferred citation is not the citation that is the "best" according to the software citation principles?
